# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: LocalServerInfo.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='LocalServerInfo.proto',
  package='com.eufylife.smarthome.protobuftool',
  syntax='proto2',
  serialized_options=None,
  serialized_pb=_b('\n\x15LocalServerInfo.proto\x12#com.eufylife.smarthome.protobuftool\"\xe6\r\n\x12LocalServerMessage\x12\x11\n\tmagic_num\x18\x01 \x01(\r\x12\x11\n\tlocalcode\x18\x02 \x01(\t\x12V\n\x01\x61\x18\x03 \x01(\x0b\x32I.com.eufylife.smarthome.protobuftool.LocalServerMessage.PingPacketMessageH\x00\x12U\n\x01\x62\x18\x04 \x01(\x0b\x32H.com.eufylife.smarthome.protobuftool.LocalServerMessage.OtaPacketMessageH\x00\x12T\n\x01\x63\x18\x05 \x01(\x0b\x32G.com.eufylife.smarthome.protobuftool.LocalServerMessage.UserDataMessageH\x00\x12S\n\x01\x64\x18\x06 \x01(\x0b\x32\x46.com.eufylife.smarthome.protobuftool.LocalServerMessage.DevinfoMessageH\x00\x1a\xb2\x01\n\x11PingPacketMessage\x12\x66\n\x04type\x18\x01 \x01(\x0e\x32X.com.eufylife.smarthome.protobuftool.LocalServerMessage.PingPacketMessage.PingPacketType\"5\n\x0ePingPacketType\x12\x10\n\x0cPING_REQUEST\x10\x00\x12\x11\n\rPING_RESPONSE\x10\x01\x1a\xf3\x05\n\x10OtaPacketMessage\x12\x64\n\x04type\x18\x01 \x01(\x0e\x32V.com.eufylife.smarthome.protobuftool.LocalServerMessage.OtaPacketMessage.OtaPacketType\x12\x14\n\x0cotafile_size\x18\x02 \x01(\r\x12o\n\x08ota_data\x18\x03 \x01(\x0b\x32].com.eufylife.smarthome.protobuftool.LocalServerMessage.OtaPacketMessage.OtaUpdateDataMessage\x12\x61\n\x05\x63\x61use\x18\x04 \x01(\x0e\x32R.com.eufylife.smarthome.protobuftool.LocalServerMessage.OtaPacketMessage.FailCause\x1aO\n\x14OtaUpdateDataMessage\x12\x12\n\nadr_offset\x18\x01 \x01(\r\x12\x15\n\rpacket_length\x18\x02 \x01(\r\x12\x0c\n\x04\x64\x61ta\x18\x03 \x01(\x0c\"\xce\x01\n\rOtaPacketType\x12\x1b\n\x17REQUEST_UPDATE_FIRMWARE\x10\x01\x12\x11\n\rPERMIT_UPDATE\x10\x02\x12\x18\n\x14OTA_UPDATE_DATA_SEND\x10\x03\x12\x16\n\x12UPDATE_DATA_VERIFY\x10\x04\x12\x14\n\x10OTA_UPDATE_ABORT\x10\x05\x12\x17\n\x13OTA_COMPLETE_NOTIFY\x10\x06\x12\x14\n\x10OTA_STATUS_FAILD\x10\x07\x12\x16\n\x12OTA_STATUS_SUCCESS\x10\x08\"m\n\tFailCause\x12\x17\n\x13\x45RASE_SECTION_FAILD\x10\x01\x12\x15\n\x11\x44\x41TA_OFFSET_ERROR\x10\x02\x12\x15\n\x11SWITCH_SIGN_FAILD\x10\x03\x12\x19\n\x15\x42RUN_UNFINISHED_ERROR\x10\x04\x1a\xdb\x01\n\x0fUserDataMessage\x12\x62\n\x04type\x18\x01 \x01(\x0e\x32T.com.eufylife.smarthome.protobuftool.LocalServerMessage.UserDataMessage.UserDataType\x12\x10\n\x08usr_data\x18\x02 \x01(\x0c\"R\n\x0cUserDataType\x12\x14\n\x10sendUsrDataToDev\x10\x00\x12\x14\n\x10getDevStatusData\x10\x01\x12\x16\n\x12sendStausDataToApp\x10\x02\x1a\xba\x01\n\x0e\x44\x65vinfoMessage\x12`\n\x04type\x18\x01 \x01(\x0e\x32R.com.eufylife.smarthome.protobuftool.LocalServerMessage.DevinfoMessage.DevInfoType\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c\"8\n\x0b\x44\x65vInfoType\x12\x13\n\x0fREQUEST_KEYCODE\x10\x01\x12\x14\n\x10RESPONSE_KEYCODE\x10\x02\x42\n\n\x08playload')
)



_LOCALSERVERMESSAGE_PINGPACKETMESSAGE_PINGPACKETTYPE = _descriptor.EnumDescriptor(
  name='PingPacketType',
  full_name='com.eufylife.smarthome.protobuftool.LocalServerMessage.PingPacketMessage.PingPacketType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PING_REQUEST', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PING_RESPONSE', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=595,
  serialized_end=648,
)
_sym_db.RegisterEnumDescriptor(_LOCALSERVERMESSAGE_PINGPACKETMESSAGE_PINGPACKETTYPE)

_LOCALSERVERMESSAGE_OTAPACKETMESSAGE_OTAPACKETTYPE = _descriptor.EnumDescriptor(
  name='OtaPacketType',
  full_name='com.eufylife.smarthome.protobuftool.LocalServerMessage.OtaPacketMessage.OtaPacketType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='REQUEST_UPDATE_FIRMWARE', index=0, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PERMIT_UPDATE', index=1, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OTA_UPDATE_DATA_SEND', index=2, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UPDATE_DATA_VERIFY', index=3, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OTA_UPDATE_ABORT', index=4, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OTA_COMPLETE_NOTIFY', index=5, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OTA_STATUS_FAILD', index=6, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OTA_STATUS_SUCCESS', index=7, number=8,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1089,
  serialized_end=1295,
)
_sym_db.RegisterEnumDescriptor(_LOCALSERVERMESSAGE_OTAPACKETMESSAGE_OTAPACKETTYPE)

_LOCALSERVERMESSAGE_OTAPACKETMESSAGE_FAILCAUSE = _descriptor.EnumDescriptor(
  name='FailCause',
  full_name='com.eufylife.smarthome.protobuftool.LocalServerMessage.OtaPacketMessage.FailCause',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ERASE_SECTION_FAILD', index=0, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DATA_OFFSET_ERROR', index=1, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SWITCH_SIGN_FAILD', index=2, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BRUN_UNFINISHED_ERROR', index=3, number=4,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1297,
  serialized_end=1406,
)
_sym_db.RegisterEnumDescriptor(_LOCALSERVERMESSAGE_OTAPACKETMESSAGE_FAILCAUSE)

_LOCALSERVERMESSAGE_USERDATAMESSAGE_USERDATATYPE = _descriptor.EnumDescriptor(
  name='UserDataType',
  full_name='com.eufylife.smarthome.protobuftool.LocalServerMessage.UserDataMessage.UserDataType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='sendUsrDataToDev', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='getDevStatusData', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='sendStausDataToApp', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1546,
  serialized_end=1628,
)
_sym_db.RegisterEnumDescriptor(_LOCALSERVERMESSAGE_USERDATAMESSAGE_USERDATATYPE)

_LOCALSERVERMESSAGE_DEVINFOMESSAGE_DEVINFOTYPE = _descriptor.EnumDescriptor(
  name='DevInfoType',
  full_name='com.eufylife.smarthome.protobuftool.LocalServerMessage.DevinfoMessage.DevInfoType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='REQUEST_KEYCODE', index=0, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RESPONSE_KEYCODE', index=1, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1761,
  serialized_end=1817,
)
_sym_db.RegisterEnumDescriptor(_LOCALSERVERMESSAGE_DEVINFOMESSAGE_DEVINFOTYPE)


_LOCALSERVERMESSAGE_PINGPACKETMESSAGE = _descriptor.Descriptor(
  name='PingPacketMessage',
  full_name='com.eufylife.smarthome.protobuftool.LocalServerMessage.PingPacketMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='com.eufylife.smarthome.protobuftool.LocalServerMessage.PingPacketMessage.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _LOCALSERVERMESSAGE_PINGPACKETMESSAGE_PINGPACKETTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=470,
  serialized_end=648,
)

_LOCALSERVERMESSAGE_OTAPACKETMESSAGE_OTAUPDATEDATAMESSAGE = _descriptor.Descriptor(
  name='OtaUpdateDataMessage',
  full_name='com.eufylife.smarthome.protobuftool.LocalServerMessage.OtaPacketMessage.OtaUpdateDataMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='adr_offset', full_name='com.eufylife.smarthome.protobuftool.LocalServerMessage.OtaPacketMessage.OtaUpdateDataMessage.adr_offset', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='packet_length', full_name='com.eufylife.smarthome.protobuftool.LocalServerMessage.OtaPacketMessage.OtaUpdateDataMessage.packet_length', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data', full_name='com.eufylife.smarthome.protobuftool.LocalServerMessage.OtaPacketMessage.OtaUpdateDataMessage.data', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1007,
  serialized_end=1086,
)

_LOCALSERVERMESSAGE_OTAPACKETMESSAGE = _descriptor.Descriptor(
  name='OtaPacketMessage',
  full_name='com.eufylife.smarthome.protobuftool.LocalServerMessage.OtaPacketMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='com.eufylife.smarthome.protobuftool.LocalServerMessage.OtaPacketMessage.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='otafile_size', full_name='com.eufylife.smarthome.protobuftool.LocalServerMessage.OtaPacketMessage.otafile_size', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ota_data', full_name='com.eufylife.smarthome.protobuftool.LocalServerMessage.OtaPacketMessage.ota_data', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cause', full_name='com.eufylife.smarthome.protobuftool.LocalServerMessage.OtaPacketMessage.cause', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_LOCALSERVERMESSAGE_OTAPACKETMESSAGE_OTAUPDATEDATAMESSAGE, ],
  enum_types=[
    _LOCALSERVERMESSAGE_OTAPACKETMESSAGE_OTAPACKETTYPE,
    _LOCALSERVERMESSAGE_OTAPACKETMESSAGE_FAILCAUSE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=651,
  serialized_end=1406,
)

_LOCALSERVERMESSAGE_USERDATAMESSAGE = _descriptor.Descriptor(
  name='UserDataMessage',
  full_name='com.eufylife.smarthome.protobuftool.LocalServerMessage.UserDataMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='com.eufylife.smarthome.protobuftool.LocalServerMessage.UserDataMessage.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='usr_data', full_name='com.eufylife.smarthome.protobuftool.LocalServerMessage.UserDataMessage.usr_data', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _LOCALSERVERMESSAGE_USERDATAMESSAGE_USERDATATYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1409,
  serialized_end=1628,
)

_LOCALSERVERMESSAGE_DEVINFOMESSAGE = _descriptor.Descriptor(
  name='DevinfoMessage',
  full_name='com.eufylife.smarthome.protobuftool.LocalServerMessage.DevinfoMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='com.eufylife.smarthome.protobuftool.LocalServerMessage.DevinfoMessage.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data', full_name='com.eufylife.smarthome.protobuftool.LocalServerMessage.DevinfoMessage.data', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _LOCALSERVERMESSAGE_DEVINFOMESSAGE_DEVINFOTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1631,
  serialized_end=1817,
)

_LOCALSERVERMESSAGE = _descriptor.Descriptor(
  name='LocalServerMessage',
  full_name='com.eufylife.smarthome.protobuftool.LocalServerMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='magic_num', full_name='com.eufylife.smarthome.protobuftool.LocalServerMessage.magic_num', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='localcode', full_name='com.eufylife.smarthome.protobuftool.LocalServerMessage.localcode', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='a', full_name='com.eufylife.smarthome.protobuftool.LocalServerMessage.a', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='b', full_name='com.eufylife.smarthome.protobuftool.LocalServerMessage.b', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='c', full_name='com.eufylife.smarthome.protobuftool.LocalServerMessage.c', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='d', full_name='com.eufylife.smarthome.protobuftool.LocalServerMessage.d', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_LOCALSERVERMESSAGE_PINGPACKETMESSAGE, _LOCALSERVERMESSAGE_OTAPACKETMESSAGE, _LOCALSERVERMESSAGE_USERDATAMESSAGE, _LOCALSERVERMESSAGE_DEVINFOMESSAGE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='playload', full_name='com.eufylife.smarthome.protobuftool.LocalServerMessage.playload',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=63,
  serialized_end=1829,
)

_LOCALSERVERMESSAGE_PINGPACKETMESSAGE.fields_by_name['type'].enum_type = _LOCALSERVERMESSAGE_PINGPACKETMESSAGE_PINGPACKETTYPE
_LOCALSERVERMESSAGE_PINGPACKETMESSAGE.containing_type = _LOCALSERVERMESSAGE
_LOCALSERVERMESSAGE_PINGPACKETMESSAGE_PINGPACKETTYPE.containing_type = _LOCALSERVERMESSAGE_PINGPACKETMESSAGE
_LOCALSERVERMESSAGE_OTAPACKETMESSAGE_OTAUPDATEDATAMESSAGE.containing_type = _LOCALSERVERMESSAGE_OTAPACKETMESSAGE
_LOCALSERVERMESSAGE_OTAPACKETMESSAGE.fields_by_name['type'].enum_type = _LOCALSERVERMESSAGE_OTAPACKETMESSAGE_OTAPACKETTYPE
_LOCALSERVERMESSAGE_OTAPACKETMESSAGE.fields_by_name['ota_data'].message_type = _LOCALSERVERMESSAGE_OTAPACKETMESSAGE_OTAUPDATEDATAMESSAGE
_LOCALSERVERMESSAGE_OTAPACKETMESSAGE.fields_by_name['cause'].enum_type = _LOCALSERVERMESSAGE_OTAPACKETMESSAGE_FAILCAUSE
_LOCALSERVERMESSAGE_OTAPACKETMESSAGE.containing_type = _LOCALSERVERMESSAGE
_LOCALSERVERMESSAGE_OTAPACKETMESSAGE_OTAPACKETTYPE.containing_type = _LOCALSERVERMESSAGE_OTAPACKETMESSAGE
_LOCALSERVERMESSAGE_OTAPACKETMESSAGE_FAILCAUSE.containing_type = _LOCALSERVERMESSAGE_OTAPACKETMESSAGE
_LOCALSERVERMESSAGE_USERDATAMESSAGE.fields_by_name['type'].enum_type = _LOCALSERVERMESSAGE_USERDATAMESSAGE_USERDATATYPE
_LOCALSERVERMESSAGE_USERDATAMESSAGE.containing_type = _LOCALSERVERMESSAGE
_LOCALSERVERMESSAGE_USERDATAMESSAGE_USERDATATYPE.containing_type = _LOCALSERVERMESSAGE_USERDATAMESSAGE
_LOCALSERVERMESSAGE_DEVINFOMESSAGE.fields_by_name['type'].enum_type = _LOCALSERVERMESSAGE_DEVINFOMESSAGE_DEVINFOTYPE
_LOCALSERVERMESSAGE_DEVINFOMESSAGE.containing_type = _LOCALSERVERMESSAGE
_LOCALSERVERMESSAGE_DEVINFOMESSAGE_DEVINFOTYPE.containing_type = _LOCALSERVERMESSAGE_DEVINFOMESSAGE
_LOCALSERVERMESSAGE.fields_by_name['a'].message_type = _LOCALSERVERMESSAGE_PINGPACKETMESSAGE
_LOCALSERVERMESSAGE.fields_by_name['b'].message_type = _LOCALSERVERMESSAGE_OTAPACKETMESSAGE
_LOCALSERVERMESSAGE.fields_by_name['c'].message_type = _LOCALSERVERMESSAGE_USERDATAMESSAGE
_LOCALSERVERMESSAGE.fields_by_name['d'].message_type = _LOCALSERVERMESSAGE_DEVINFOMESSAGE
_LOCALSERVERMESSAGE.oneofs_by_name['playload'].fields.append(
  _LOCALSERVERMESSAGE.fields_by_name['a'])
_LOCALSERVERMESSAGE.fields_by_name['a'].containing_oneof = _LOCALSERVERMESSAGE.oneofs_by_name['playload']
_LOCALSERVERMESSAGE.oneofs_by_name['playload'].fields.append(
  _LOCALSERVERMESSAGE.fields_by_name['b'])
_LOCALSERVERMESSAGE.fields_by_name['b'].containing_oneof = _LOCALSERVERMESSAGE.oneofs_by_name['playload']
_LOCALSERVERMESSAGE.oneofs_by_name['playload'].fields.append(
  _LOCALSERVERMESSAGE.fields_by_name['c'])
_LOCALSERVERMESSAGE.fields_by_name['c'].containing_oneof = _LOCALSERVERMESSAGE.oneofs_by_name['playload']
_LOCALSERVERMESSAGE.oneofs_by_name['playload'].fields.append(
  _LOCALSERVERMESSAGE.fields_by_name['d'])
_LOCALSERVERMESSAGE.fields_by_name['d'].containing_oneof = _LOCALSERVERMESSAGE.oneofs_by_name['playload']
DESCRIPTOR.message_types_by_name['LocalServerMessage'] = _LOCALSERVERMESSAGE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

LocalServerMessage = _reflection.GeneratedProtocolMessageType('LocalServerMessage', (_message.Message,), dict(

  PingPacketMessage = _reflection.GeneratedProtocolMessageType('PingPacketMessage', (_message.Message,), dict(
    DESCRIPTOR = _LOCALSERVERMESSAGE_PINGPACKETMESSAGE,
    __module__ = 'LocalServerInfo_pb2'
    # @@protoc_insertion_point(class_scope:com.eufylife.smarthome.protobuftool.LocalServerMessage.PingPacketMessage)
    ))
  ,

  OtaPacketMessage = _reflection.GeneratedProtocolMessageType('OtaPacketMessage', (_message.Message,), dict(

    OtaUpdateDataMessage = _reflection.GeneratedProtocolMessageType('OtaUpdateDataMessage', (_message.Message,), dict(
      DESCRIPTOR = _LOCALSERVERMESSAGE_OTAPACKETMESSAGE_OTAUPDATEDATAMESSAGE,
      __module__ = 'LocalServerInfo_pb2'
      # @@protoc_insertion_point(class_scope:com.eufylife.smarthome.protobuftool.LocalServerMessage.OtaPacketMessage.OtaUpdateDataMessage)
      ))
    ,
    DESCRIPTOR = _LOCALSERVERMESSAGE_OTAPACKETMESSAGE,
    __module__ = 'LocalServerInfo_pb2'
    # @@protoc_insertion_point(class_scope:com.eufylife.smarthome.protobuftool.LocalServerMessage.OtaPacketMessage)
    ))
  ,

  UserDataMessage = _reflection.GeneratedProtocolMessageType('UserDataMessage', (_message.Message,), dict(
    DESCRIPTOR = _LOCALSERVERMESSAGE_USERDATAMESSAGE,
    __module__ = 'LocalServerInfo_pb2'
    # @@protoc_insertion_point(class_scope:com.eufylife.smarthome.protobuftool.LocalServerMessage.UserDataMessage)
    ))
  ,

  DevinfoMessage = _reflection.GeneratedProtocolMessageType('DevinfoMessage', (_message.Message,), dict(
    DESCRIPTOR = _LOCALSERVERMESSAGE_DEVINFOMESSAGE,
    __module__ = 'LocalServerInfo_pb2'
    # @@protoc_insertion_point(class_scope:com.eufylife.smarthome.protobuftool.LocalServerMessage.DevinfoMessage)
    ))
  ,
  DESCRIPTOR = _LOCALSERVERMESSAGE,
  __module__ = 'LocalServerInfo_pb2'
  # @@protoc_insertion_point(class_scope:com.eufylife.smarthome.protobuftool.LocalServerMessage)
  ))
_sym_db.RegisterMessage(LocalServerMessage)
_sym_db.RegisterMessage(LocalServerMessage.PingPacketMessage)
_sym_db.RegisterMessage(LocalServerMessage.OtaPacketMessage)
_sym_db.RegisterMessage(LocalServerMessage.OtaPacketMessage.OtaUpdateDataMessage)
_sym_db.RegisterMessage(LocalServerMessage.UserDataMessage)
_sym_db.RegisterMessage(LocalServerMessage.DevinfoMessage)


# @@protoc_insertion_point(module_scope)



import socket
from robovac import LocalServerInfo_pb2
import random
from Crypto.Cipher import AES
from typing import Union
import struct
from enum import Enum
import requests


_AES_KEY = bytearray([0x24, 0x4E, 0x6D, 0x8A, 0x56, 0xAC, 0x87, 0x91, 0x24, 0x43, 0x2D, 0x8B, 0x6C, 0xBC, 0xA2, 0xC4])
_AES_IV = bytearray([0x77, 0x24, 0x56, 0xF2, 0xA7, 0x66, 0x4C, 0xF3, 0x39, 0x2C, 0x35, 0x97, 0xE9, 0x3E, 0x57, 0x47])


class EufyApiError(Exception):
    """ Exception raised when there's a problem communicating with the Eufy API """


def get_local_code(username: str, password: str, ip_address: str):
    """
    Retrieve the local code for a device using the EufyHome account's username and password.

    Based on a similar method in the google/python-lakeside project:
    https://github.com/google/python-lakeside/blob/c3f2fef2ca35aac49d2271b436c144b1b059aa6a/lakeside/__init__.py#L30
    """
    client_id = 'eufyhome-app'
    client_secret = 'GQCpr9dSp3uQpsOMgJ4xQ'

    login_payload = {'client_id': client_id, 'client_Secret': client_secret, 'email': username, 'password': password}
    login_request = requests.post("https://home-api.eufylife.com/v1/user/email/login", json=login_payload)

    if login_request.status_code != 200:
        raise EufyApiError('Could not authenticate with Eufy API. Is your username and password correct?')

    token = login_request.json()['access_token']
    headers = {'token': token, 'category': 'Home'}
    devices_request = requests.get('https://home-api.eufylife.com/v1/device/list/devices-and-groups', headers=headers)

    if devices_request.status_code != 200:
        raise EufyApiError('Could not list devices from Eufy API.')

    devices_from_api = devices_request.json()

    for item in devices_from_api['items']:
        if 'device' in item and item['device']['wifi']['lan_ip_addr'] == ip_address:
            return item['device']['local_code']

    raise EufyApiError('Cannot find local code for device with given IP address. Check that the IP address is correct.')


def _encrypt(data):
    """ Encrypt data using the Eufy AES key and IV. Handles padding to a 16 byte interval. """
    cipher = AES.new(bytes(_AES_KEY), AES.MODE_CBC, bytes(_AES_IV))

    # Pad to 16 bytes for AES CBC
    for i in range(16 - (len(data) % 16)):
        data += b'\0'

    return cipher.encrypt(data)


def _decrypt(data):
    """ Decrypt data using the Eufy AES key and IV. """
    cipher = AES.new(bytes(_AES_KEY), AES.MODE_CBC, bytes(_AES_IV))
    return cipher.decrypt(data)


def _build_robovac_command(mode, command):
    """ Compile the given mode and command into the bytes data sent to the RoboVac. """
    mcu_ota_header_0xa5 = 0xA5
    cmd_data = (mode.value + command.value)

    return bytes([mcu_ota_header_0xa5, mode.value, command.value, cmd_data, 0xFA])


class RobovacModes(Enum):
    """ Enum representations of all the possible RoboVac modes. """

    WORK = 0xE1
    SET_SPEED = 0xE8
    FIND_ME = 0xEC
    GO_FORWARD = 0xE2
    GO_LEFT = 0xE4
    GO_RIGHT = 0xE5
    GO_BACKWARD = 0xE3


class RobovacCommands(Enum):
    """ Enum representations of all the possible RoboVac commands. """

    AUTO_CLEAN = 0x02
    SINGLE_ROOM_CLEAN = 0x05
    SPOT_CLEAN = 0x01
    EDGE_CLEAN = 0x04
    STOP_CLEAN = 0x00
    GO_HOME = 0x03

    SLOW_SPEED = 0x00
    FAST_SPEED = 0x01

    START_RING = 0x01
    STOP_RING = 0x00

    MOVE = 0x01


class RobovacStatus:
    """ Status reported by the RoboVac. """

    def __init__(self,
                 find_me,
                 water_tank_status,
                 mode,
                 speed,
                 charger_status,
                 battery_capacity,
                 error_code,
                 stop):
        self.find_me = find_me
        self.water_tank_status = water_tank_status
        self.mode = mode
        self.speed = speed
        self.charger_status = charger_status
        self.battery_capacity = battery_capacity
        self.error_code = error_code
        self.stop = stop

    def __str__(self) -> str:
        return f'[FIND_ME: {self.find_me}, WATER_TANK: {self.water_tank_status}, MODE: {self.mode}, SPEED: {self.speed}, CHARGER_STATUS: {self.charger_status}, BATTERY_CAPACITY: {self.battery_capacity}, ERROR_CODE: {self.error_code}, STOP: {self.stop}]'


class Robovac:
    @staticmethod
    def _parse_local_server_message_from_decrypted_response(decrypted_response):
        """ Parse a decrypted response into a Protobuf Local Server Message """

        # First 2 bytes indicate length of the actual data
        length = struct.unpack("<H", decrypted_response[0:2])[0]
        protobuf_data = decrypted_response[2:length + 2]

        message = LocalServerInfo_pb2.LocalServerMessage()
        message.ParseFromString(protobuf_data)
        return message

    def __init__(self, ip: str, local_code: str, port=55556):
        self.ip = ip
        self.port = port
        self.local_code = local_code
        self.s = socket.socket(socket.AF_INET, socket.SOCK_STREAM)

    def connect(self) -> None:
        """ Connect to the RoboVac at the given IP and port """
        self.s.connect((self.ip, self.port))

    def get_status(self) -> RobovacStatus:
        """ Get the status of the RoboVac device (battery level, mode, charging, etc). """
        message = self._build_get_device_status_user_data_message()
        robovac_response = self._send_packet(message, True)
        received_status_bytes = robovac_response.c.usr_data
        received_status_ints = [x for x in received_status_bytes]

        return RobovacStatus(
            1 if received_status_ints[6] & 4 > 0 else 0,
            1 if received_status_ints[6] & 2 > 0 else 0,
            received_status_ints[1] & 255,
            received_status_ints[8] & 255,
            received_status_ints[11] & 255,
            received_status_ints[10] & 255,
            received_status_ints[12] & 255,
            received_status_ints[13] & 255
        )

    def start_auto_clean(self):
        """ Tell the RoboVac to start its auto-clean programme. """
        command = _build_robovac_command(RobovacModes.WORK, RobovacCommands.AUTO_CLEAN)
        message = self._build_command_user_data_message(command)

        self._send_packet(message, False)

    def start_spot_clean(self):
        """ Tell the RoboVac to start its spot-clean programme. """
        command = _build_robovac_command(RobovacModes.WORK, RobovacCommands.SPOT_CLEAN)
        message = self._build_command_user_data_message(command)

        self._send_packet(message, False)

    def start_edge_clean(self):
        """ Tell the RoboVac to start its edge-clean programme. """
        command = _build_robovac_command(RobovacModes.WORK, RobovacCommands.EDGE_CLEAN)
        message = self._build_command_user_data_message(command)

        self._send_packet(message, False)

    def start_single_room_clean(self):
        """ Tell the RoboVac to clean a single room. """
        command = _build_robovac_command(RobovacModes.WORK, RobovacCommands.SINGLE_ROOM_CLEAN)
        message = self._build_command_user_data_message(command)

        self._send_packet(message, False)

    def stop(self):
        """ Tell the RoboVac to stop cleaning. The RoboVac will not return to its charging base. """
        command = _build_robovac_command(RobovacModes.WORK, RobovacCommands.STOP_CLEAN)
        message = self._build_command_user_data_message(command)

        self._send_packet(message, False)

    def go_home(self):
        """ Tell the RoboVac to return to its charging base. """
        command = _build_robovac_command(RobovacModes.WORK, RobovacCommands.GO_HOME)
        message = self._build_command_user_data_message(command)

        self._send_packet(message, False)

    def start_find_me(self):
        """ Start the 'find me' mode. The RoboVac will repeatedly play a chime. """
        command = _build_robovac_command(RobovacModes.FIND_ME, RobovacCommands.START_RING)
        message = self._build_command_user_data_message(command)

        self._send_packet(message, False)

    def stop_find_me(self):
        """ Stop the 'find me' mode. """
        command = _build_robovac_command(RobovacModes.FIND_ME, RobovacCommands.STOP_RING)
        message = self._build_command_user_data_message(command)

        self._send_packet(message, False)

    def use_normal_speed(self):
        """ Tell the RoboVac to use the standard fan speed. """
        command = _build_robovac_command(RobovacModes.SET_SPEED, RobovacCommands.SLOW_SPEED)
        message = self._build_command_user_data_message(command)

        self._send_packet(message, False)

    def use_max_speed(self):
        """ Tell the RoboVac to use the maximum possible fan speed. """
        command = _build_robovac_command(RobovacModes.SET_SPEED, RobovacCommands.FAST_SPEED)
        message = self._build_command_user_data_message(command)

        self._send_packet(message, False)

    def go_forward(self):
        """ Tell the RoboVac to move forward without vacuuming. """
        command = _build_robovac_command(RobovacModes.GO_FORWARD, RobovacCommands.MOVE)
        message = self._build_command_user_data_message(command)

        self._send_packet(message, False)

    def go_backward(self):
        """ Tell the RoboVac to move backward without vacuuming. """
        command = _build_robovac_command(RobovacModes.GO_BACKWARD, RobovacCommands.MOVE)
        message = self._build_command_user_data_message(command)

        self._send_packet(message, False)

    def go_left(self):
        """ Tell the RoboVac to turn left without vacuuming. """
        command = _build_robovac_command(RobovacModes.GO_LEFT, RobovacCommands.MOVE)
        message = self._build_command_user_data_message(command)

        self._send_packet(message, False)

    def go_right(self):
        """ Tell the RoboVac to turn right without vacuuming. """
        command = _build_robovac_command(RobovacModes.GO_RIGHT, RobovacCommands.MOVE)
        message = self._build_command_user_data_message(command)

        self._send_packet(message, False)

    def _build_command_user_data_message(self, command_payload) -> LocalServerInfo_pb2.LocalServerMessage:
        """ Build the Protobuf message in which a given command will be sent. """
        magic_number = self._get_magic_number()
        message = LocalServerInfo_pb2.LocalServerMessage()
        message.magic_num = magic_number
        message.localcode = self.local_code
        message.c.type = 0
        message.c.usr_data = command_payload

        return message

    def _build_get_device_status_user_data_message(self) -> LocalServerInfo_pb2.LocalServerMessage:
        """ Build the Protobuf message to get the RoboVac's status. """
        magic_number = self._get_magic_number()
        message = LocalServerInfo_pb2.LocalServerMessage()
        message.localcode = self.local_code
        message.magic_num = magic_number
        message.c.type = 1

        return message

    def _get_magic_number(self) -> int:
        """ Send a ping packet and parse the response in order to retrieve the next magic number."""
        ping = LocalServerInfo_pb2.LocalServerMessage()
        ping.localcode = self.local_code
        ping.magic_num = random.randrange(3000000)

        ping.a.type = 0

        pong = self._send_packet(ping, True)
        return pong.magic_num + 1

    def _send_packet(self,
                     packet: LocalServerInfo_pb2.LocalServerMessage,
                     receive: True) -> Union[None, LocalServerInfo_pb2.LocalServerMessage]:
        """
        Send a packet to the RoboVac. This method handles all the required encryption.

        Will attempt to reconnect to the RoboVac if sending a packet fails.
        :param receive: If true, the packet sent in reply by the RoboVac will be parsed and returned.
        """
        raw_packet_data = packet.SerializeToString()
        encrypted_packet_data = _encrypt(raw_packet_data)

        try:
            self.s.send(encrypted_packet_data)
        except:
            self.connect()
            self.s.send(encrypted_packet_data )

        if not receive:
            return None

        response_from_robovac = self.s.recv(1024)
        decrypted_response = _decrypt(response_from_robovac)
        return Robovac._parse_local_server_message_from_decrypted_response(decrypted_response)



import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="robovac",
    version="0.0.7",
    author="BnMcG",
    author_email="ben@bmagee.com",
    description="Python API for communicating with Eufy RoboVac 11c devices",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/bnmcg/pyrobovac",
    packages=setuptools.find_packages(),
    install_requires=[
        'protobuf',
        'pycryptodome',
        'six',
        'requests'
    ],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: Apache Software License",
        "Operating System :: OS Independent",
    ],
)
